@@ -18,6 +18,8 @@
 #include <QMimeType>
 #include <QPointer>
 
+#include <optional>
+
 class ArkViewer : public KParts::MainWindow, public Ui::ArkViewer
 {
     Q_OBJECT
@@ -25,20 +27,21 @@ class ArkViewer : public KParts::MainWindow, public Ui::ArkViewer
 public:
     ~ArkViewer() override;
 
-    static void view(const QString& fileName, const QString& entryPath = QString());
+    static void view(const QString& fileName, const QString& entryPath = QString(), const QMimeType& mimeType = QMimeType());
 
 private:
     explicit ArkViewer();
 
     static KService::Ptr getExternalViewer(const QString& mimeType);
-    static KService::Ptr getInternalViewer(const QString& mimeType);
+    static std::optional<KPluginMetaData> getInternalViewer(const QString& mimeType);
 
     static void openExternalViewer(const KService::Ptr viewer, const QString& fileName);
-    static void openInternalViewer(const KService::Ptr viewer, const QString& fileName, const QString& entryPath, const QMimeType& mimeType);
+
+    static void openInternalViewer(const KPluginMetaData& viewer, const QString& fileName, const QString& entryPath, const QMimeType& mimeType);
 
     static bool askViewAsPlainText(const QMimeType& mimeType);
 
-    bool viewInInternalViewer(const KService::Ptr viewer, const QString& fileName, const QString &entryPath, const QMimeType& mimeType);
+    bool viewInInternalViewer(const KPluginMetaData& viewer, const QString& fileName, const QString& entryPath, const QMimeType& mimeType);
 
 private Q_SLOTS:
     void aboutKPart();
